@@ -162,6 +162,19 @@ class TerminalMixin:
         else:
             return None
 
+    def get_session(self, session_id):
+        try:
+            resp = self.http.get('session-detail', pk=session_id)
+        except (RequestError, ResponseError) as e:
+            logger.error(e)
+            return None
+
+        if resp.status_code == 200:
+            return resp.json()
+        else:
+            logger.error("Session list response code not 200")
+            return None
+
     def finish_session(self, session_data):
         try:
             session_id = session_data["id"]
