@@ -29,8 +29,8 @@ API_URL_MAPPING = {
     'terminal-config': '/api/v1/terminal/terminals/config/',
     'token-asset': '/api/users/v1/connection-token/?token=%s',
     'domain-detail': '/api/assets/v1/domain/%s/',
-    'ftp-log-list': '/api/audits/v1/ftp-log/',
-    'sql-log-list': '/api/v1/audits/sql-log/',
+    'ftp-log-list': '/api/audits/v1/ftp-logs/',
+    'sql-log-list': '/api/v1/audits/sql-logs/',
     'org-list': '/api/orgs/v1/orgs/',
     'system-user-cmd-filter-rule-list': '/api/assets/v1/system-user/%s/cmd-filter-rules/',
     'terminal-registration': '/api/terminal/v2/terminal-registrations/',
